// $Id: drawingarea.cc,v 1.13 2002/05/14 08:25:44 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *
 *  Copyright (C) 1998  Joe Pfeiffer, pfeiffer@cs.nmsu.edu
 *  Rewritten for new API in 1999 by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "drawingarea.hh"

static Gtk_DrawingArea Gtk_DrawingArea(false);

const std::string Gtk_DrawingArea::TypeName(const Widget &w) const
{  return GtkPrefix()+"DrawingArea";
}

const std::string Gtk_DrawingArea::IncludeName(const Widget &w) const
{  return Configuration.GtkmmIncludePath()+"drawingarea.h";
}

Gtk_DrawingArea::Gtk_DrawingArea(bool base_class_init)
{  if (!base_class_init) Writer["GtkDrawingArea"]=this;
}

